БГУИР - Вопросы и предложения, а также комментарии и замечания о работе портала

На главную | | Карта сайта | | e-mail |
| en | ru
Схема корпусов | Обратная связь | Форум | Почта | Телефоны БГУИР
Об университете
• История
• Символика и устав БГУИР
• Структура университета
• Почётные доктора БГУИР
• Одно окно
• Система менеджмента университета
• Телефонный справочник БГУИР
• Международное сотрудничество
• Спорт в университете
• Пресс-служба
• СМИ о БГУИР
• Фотогалерея
Образование
• Абитуриентам
• Факультеты
• Кафедры
• Расписание занятий
• Расписание экзаменов
• Стипендии
• Оплата обучения
• Магистратура
• Аспирантура и докторантура
• Научно-методический совет университета
• Советы по защите диссертаций
• Иностранным студентам
• Информационная база УМУ
• Центр языковой подготовки по иностранным языкам
• Повышение квалификации, переподготовка и стажировка
• Взаимодействие с заказчиками кадров
Наука
• Центр трансфера технологий
• Подразделения НИЧ
• Международный Алферовский фонд поддержки образования и науки
• Международный научно-образовательно-инновационный центр инфокоммуникационных технологий и защиты информации
• Научные школы
• Инженерно-образовательный центр ИЗОВАК-БГУИР
• Конференции БГУИР
• Конференции, семинары и курсы
• Конкурсы и гранты
• Экспертные комиссии
• Публикации
Информация
• Система "Расчет"
• Приказы
• Страница юриста
• Компьютерная сеть БГУИР
• Энерго- и ресурсосбережение
• Материалы ВКС
Идеологическая работа
• Структура управления
• Документация
• Нравственный кодекс БГУИР
• Центр культурно-массовой работы
• Молодежные объединения
• Социально-педагогическая и психологическая служба
• Отдел методической и воспитательной работы
• Социальная поддержка
• Ко дню информирования
• Час Фемиды
• Проект "Мой стиль жизни сегодня - Моё здоровье и успех завтра"
Главная
# Ваши вопросы и предложения, а также комментарии и замечания о работе портала Данный сервис предназначен для связи пользователей с администраторами портала. Поле 'Вопросы/Комментарии' является обязательным для заполнения. При формулировании вопросов и предложений старайтесь изложить свои мысли четко и ясно. Если комментарии связаны с невозможностью выполнить какое-либо действие или возникает какая-нибудь ошибка в работе портала, постарайтесь подробно описать последовательность действий, которая привела к возникновению данной ситуации. Кроме этого, укажите, пожалуйста, название и версию браузера, которым Вы пользуетесь, чтобы разработчики могли воспроизвести сложившуюся ситуацию. Администраторы портала благодарят Вас за оказанное содействие.
Имя |
Контактная информация |
Вопросы/Комментарии * |
* - поля обязательные для ввода
разработка: © Центр Информатизации и Инновационных Разработок, 2002-2014